==> abe-cli-0.0.9.tgz: package/src/server/public/scripts/modules/EditorBlock.js <==
import {IframeNode} from '../utils/iframe'
import {nextSibling} from '../utils/dom'
import Color from '../utils/color-picker'
import RichText from '../utils/rich-texarea'
import on from 'on'

export default class EditorBlock {
  constructor() {
  	this.color = new Color(document.querySelector('.wysiwyg-popup'))

    this._removeblock = [].slice.call(document.querySelectorAll('.remove-block'))
    this._handleClickRemoveBlock = this._clickRemoveBlock.bind(this)
    
    this._addblock = [].slice.call(document.querySelectorAll('.add-block'))
    this._handleClickAddBlock = this._clickAddBlock.bind(this)

    this.onNewBlock = on(this)
    this.onRemoveBlock = on(this)

    this._bindEvents()
  }

  /**
   * bind events
   * @return {[type]} [description]
   */
  _bindEvents() {
    this._removeblock.forEach((block) => {
      block.addEventListener('click', this._handleClickRemoveBlock)
    })
    this._addblock.forEach((block) => {
      block.addEventListener('click', this._handleClickAddBlock)
    })
  }

  /**
   * event remove block
   * @param  {[type]} e [description]
   * @return {[type]}   [description]
   */
  _clickRemoveBlock(e) {
    var target = e.currentTarget
      , listItem = target.parentNode.querySelectorAll('.list-group-item')
      , lastItem = listItem[listItem.length - 1]
      , blockText = IframeNode('#page-template', '.insert-' + target.parentNode.getAttribute('data-block'))[0]
      , blockHtml = unescape(blockText.innerHTML)
      , labels = [].slice.call(lastItem.querySelectorAll('label'))

    Array.prototype.forEach.call(labels, (label) => {
      var iframeRef = IframeNode('#page-template', '[data-abe="' + label.getAttribute('for') + '"]')[0]
      iframeRef.remove()
    })

    if(typeof listItem !== 'undefined' && listItem !== null && listItem.length > 1) {
      lastItem.remove()
    }else {
      lastItem.style.display = 'none'
    }

    this.onRemoveBlock._fire()
  }

  /**
   * event add new block
   * @param  {[type]} e [description]
   * @return {[type]}   [description]
   */
  _clickAddBlock(e) {
    let target = e.currentTarget
    var dataLink = target.getAttribute('data-id-link')
    var prevListItem = target.parentNode.querySelectorAll('.list-group-item')
    prevListItem = prevListItem[prevListItem.length - 1]

    var attrId = (typeof dataLink !== 'undefined' && dataLink !== null) ? 'data-id-link' : 'data-id'
      , htmlBlockItem = prevListItem.innerHTML
      , itemNumber = 0
      , newNumber = 0
      , listGroupItem = target.parentNode.querySelectorAll('.list-group-item').length
      , rex = new RegExp(itemNumber, 'g')

    if(listGroupItem > 1 || (listGroupItem === 1 && prevListItem.style.display !== 'none')) {
      newNumber = this._createNewBlock(prevListItem, itemNumber, newNumber)
      rex = new RegExp(newNumber - 1, 'g')
    }else {
      prevListItem.style.display = 'block'
    }

    prevListItem = target.parentNode.querySelectorAll('.list-group-item')
    prevListItem = prevListItem[prevListItem.length - 1]
    var prevButton = prevListItem.querySelector('button')
    var dataTarget = prevButton.getAttribute('data-target')
    var newTarget = dataTarget.replace(rex, newNumber)

    var contentListItem = prevListItem.querySelector(dataTarget)
    contentListItem.setAttribute('id', newTarget.slice(1))
    contentListItem.setAttribute(attrId, newTarget.slice(1))

    prevButton.setAttribute('data-target', newTarget)
    this._insertNewBlock(prevListItem.parentNode.getAttribute('data-block'), newNumber)
    var labels = prevListItem.querySelectorAll('label')
    Array.prototype.forEach.call(labels, (label) => {
      label.innerHTML = label.innerHTML.replace(rex, newNumber)
    })

    this.onNewBlock._fire()
  }

  /**
   * insert node page side
   * @param  {[type]} dataBlock [description]
   * @param  {[type]} newNumber [description]
   * @return {[type]}           [description]
   */
  _insertNewBlock(dataBlock, newNumber) {
    var blockContent = IframeNode('#page-template', `.insert-${dataBlock}`)[0]
    var blockHtml = unescape(blockContent.innerHTML).replace(/\[0\]-/g, '[' + newNumber + ']-')

    var newBlock = document.createElement('abe')
    newBlock.innerHTML = blockHtml

    var childs = [].slice.call(newBlock.childNodes)
    Array.prototype.forEach.call(childs, (child) => {
      blockContent.parentNode.insertBefore(child, blockContent)
    })
  }

  /**
   * remove default value into a form
   * @param  {[type]} block [description]
   * @return {[type]}       [description]
   */
  _unValueForm(block) {

    var inputs = [].slice.call(block.querySelectorAll('input'))
    Array.prototype.forEach.call(inputs, (input) => {
      input.value = ''
    })

    var textareas = [].slice.call(block.querySelectorAll('textarea'))
    Array.prototype.forEach.call(textareas, (textarea) => {
      textarea.value = ''
    })

    // var contenteditables = [].slice.call(block.querySelectorAll('[contenteditable]'))
    // Array.prototype.forEach.call(contenteditables, (contenteditable) => {
    //   contenteditable.innerHTML = ''
    // })

    var selects = [].slice.call(block.querySelectorAll('select'))
    Array.prototype.forEach.call(selects, (select) => {
      select.value = ''

      var options = [].slice.call(select.querySelectorAll('option'))
      Array.prototype.forEach.call(options, (option) => {
        option.removeAttribute('selected')
      })
    })
  }

  /**
   * Create admin side block
   * @param  {[type]} prevListItem [description]
   * @param  {[type]} itemNumber   [description]
   * @param  {[type]} newNumber    [description]
   * @return {[type]}              [description]
   */
  _createNewBlock(prevListItem, itemNumber, newNumber) {
    var htmlBlockItem = prevListItem.innerHTML

    htmlBlockItem = htmlBlockItem.replace(/\[(.*?)\]/g, function(val, $_1) {
      itemNumber = parseInt($_1)
      newNumber = itemNumber + 1
      return '[' + newNumber + ']';
    })
    var rex = new RegExp(itemNumber, 'g')
    
    var dataBlock = prevListItem.getAttribute('data-block').replace(rex, newNumber)

    var newBlock = document.createElement('div')
    newBlock.classList.add('list-group-item')
    newBlock.setAttribute('data-block', dataBlock)
    newBlock.innerHTML = htmlBlockItem
    var next = nextSibling(prevListItem.parentNode, prevListItem)
    prevListItem.parentNode.insertBefore(newBlock, next)
    this._unValueForm(newBlock)

    var richs = [].slice.call(newBlock.querySelectorAll('[contenteditable]'))
    if(typeof richs !== 'undefined' && richs !== null && richs.length > 0) {
      Array.prototype.forEach.call(richs, (rich) => {
        rich.remove()
      })
      var newRichs = [].slice.call(newBlock.querySelectorAll('.rich'))
      Array.prototype.forEach.call(newRichs, (newRich) => {
        new RichText(newRich, this.color)
      })
    }

    return newNumber
  }
}

==> abe-cli-0.2.18.tgz: package/src/server/public/scripts/modules/EditorBlock.js <==
import {IframeNode, IframeCommentNode} from '../utils/iframe'
import {nextSibling} from '../utils/dom'
import Color from '../utils/color-picker'
import RichText from '../utils/rich-texarea'
import Json from '../modules/EditorJson'
import on from 'on'

export default class EditorBlock {
  constructor() {
    this._json = Json.instance
  	this.color = new Color(document.querySelector('.wysiwyg-popup'))

    this._removeblock = [].slice.call(document.querySelectorAll('.remove-block'))
    this._handleClickRemoveBlock = this._clickRemoveBlock.bind(this)
    
    this._addblock = [].slice.call(document.querySelectorAll('.add-block'))
    this._handleClickAddBlock = this._clickAddBlock.bind(this)

    this.onNewBlock = on(this)
    this.onRemoveBlock = on(this)

    this._bindEvents()
  }

  /**
   * bind events
   * @return {[type]} [description]
   */
  _bindEvents() {
    this._removeblock.forEach((block) => {
      block.addEventListener('click', this._handleClickRemoveBlock)
    })
    this._addblock.forEach((block) => {
      block.addEventListener('click', this._handleClickAddBlock)
    })
  }

  /**
   * event remove block
   * @param  {[type]} e [description]
   * @return {[type]}   [description]
   */
  _clickRemoveBlock(e) {
    var target = e.currentTarget
      , listItem = target.parentNode.querySelectorAll('.list-group-item')
      , lastItem = listItem[listItem.length - 1]

    var iframeRefAll = IframeNode('#page-template', `[data-abe-block="${lastItem.getAttribute('data-block')}"]`)

    Array.prototype.forEach.call(iframeRefAll, (iframeRef) => {
      iframeRef.remove()
    })

    if(typeof listItem !== 'undefined' && listItem !== null && listItem.length > 1) {
      lastItem.remove()
    }else {
      lastItem.style.display = 'none'
    }

    this._json.data[target.parentNode.getAttribute('data-block')] = []
    this.onRemoveBlock._fire()
  }

  /**
   * event add new block
   * @param  {[type]} e [description]
   * @return {[type]}   [description]
   */
  _clickAddBlock(e) {
    let target = e.currentTarget
    var dataLink = target.getAttribute('data-id-link')
    var prevListItem = target.parentNode.querySelectorAll('.list-group-item')
    prevListItem = prevListItem[prevListItem.length - 1]

    var attrId = (typeof dataLink !== 'undefined' && dataLink !== null) ? 'data-id-link' : 'data-id'
      , htmlBlockItem = prevListItem.innerHTML
      , itemNumber = 0
      , newNumber = 0
      , listGroupItem = target.parentNode.querySelectorAll('.list-group-item').length
      , rex = new RegExp(itemNumber, 'g')

    if(listGroupItem > 1 || (listGroupItem === 1 && prevListItem.style.display !== 'none')) {
      newNumber = this._createNewBlock(prevListItem, itemNumber, newNumber)
      rex = new RegExp(newNumber - 1, 'g')
    }else {
      prevListItem.style.display = 'block'
    }

    prevListItem = target.parentNode.querySelectorAll('.list-group-item')
    prevListItem = prevListItem[prevListItem.length - 1]
    var prevButton = prevListItem.querySelector('button')
    var dataTarget = prevButton.getAttribute('data-target')
    var newTarget = dataTarget.replace(rex, newNumber)

    var contentListItem = prevListItem.querySelector(dataTarget)
    contentListItem.setAttribute('id', newTarget.slice(1))
    contentListItem.setAttribute(attrId, newTarget.slice(1))

    prevButton.setAttribute('data-target', newTarget)
    this._insertNewBlock(prevListItem.parentNode.getAttribute('data-block'), newNumber)
    var labels = prevListItem.querySelectorAll('label')
    Array.prototype.forEach.call(labels, (label) => {
      label.innerHTML = label.innerHTML.replace(rex, newNumber)
    })

    this.onNewBlock._fire()
  }

  /**
   * insert node page side
   * @param  {[type]} dataBlock [description]
   * @param  {[type]} newNumber [description]
   * @return {[type]}           [description]
   */
  _insertNewBlock(dataBlock, newNumber) {
    // var blockContent = IframeNode('#page-template', `.insert-${dataBlock}`)[0]
    // var blockHtml = unescape(blockContent.innerHTML).replace(/\[0\]-/g, '[' + newNumber + ']-')

    var blockContent = IframeCommentNode('#page-template', dataBlock)
    if(typeof blockContent !== 'undefined' && blockContent !== null && blockContent.length > 0) {
      blockContent = blockContent[0]
      var blockHtml = unescape(blockContent.textContent.replace(/\[\[([\S\s]*?)\]\]/, '')).replace(/\[0\]-/g, '[' + newNumber + ']-')

      var newBlock = document.createElement('abe')
      newBlock.innerHTML = blockHtml

      var childs = [].slice.call(newBlock.childNodes)
      console.log(childs)
      Array.prototype.forEach.call(childs, (child) => {
        if(typeof child.setAttribute !== 'undefined' && child.setAttribute !== null) {
          child.setAttribute('data-abe-block', dataBlock + newNumber)
        }
        blockContent.parentNode.insertBefore(child, blockContent)
      })
      
    }
  }

  /**
   * remove default value into a form
   * @param  {[type]} block [description]
   * @return {[type]}       [description]
   */
  _unValueForm(block) {

    var inputs = [].slice.call(block.querySelectorAll('input'))
    Array.prototype.forEach.call(inputs, (input) => {
      input.value = ''
    })

    var textareas = [].slice.call(block.querySelectorAll('textarea'))
    Array.prototype.forEach.call(textareas, (textarea) => {
      textarea.value = ''
    })

    // var contenteditables = [].slice.call(block.querySelectorAll('[contenteditable]'))
    // Array.prototype.forEach.call(contenteditables, (contenteditable) => {
    //   contenteditable.innerHTML = ''
    // })

    var selects = [].slice.call(block.querySelectorAll('select'))
    Array.prototype.forEach.call(selects, (select) => {
      select.value = ''

      var options = [].slice.call(select.querySelectorAll('option'))
      Array.prototype.forEach.call(options, (option) => {
        option.removeAttribute('selected')
      })
    })
  }

  /**
   * Create admin side block
   * @param  {[type]} prevListItem [description]
   * @param  {[type]} itemNumber   [description]
   * @param  {[type]} newNumber    [description]
   * @return {[type]}              [description]
   */
  _createNewBlock(prevListItem, itemNumber, newNumber) {
    var htmlBlockItem = prevListItem.innerHTML

    htmlBlockItem = htmlBlockItem.replace(/\[(.*?)\]/g, function(val, $_1) {
      itemNumber = parseInt($_1)
      newNumber = itemNumber + 1
      return '[' + newNumber + ']';
    })
    var rex = new RegExp(itemNumber, 'g')
    
    var dataBlock = prevListItem.getAttribute('data-block').replace(rex, newNumber)

    var newBlock = document.createElement('div')
    newBlock.classList.add('list-group-item')
    newBlock.setAttribute('data-block', dataBlock)
    newBlock.innerHTML = htmlBlockItem
    var next = nextSibling(prevListItem.parentNode, prevListItem)
    prevListItem.parentNode.insertBefore(newBlock, next)
    this._unValueForm(newBlock)

    var richs = [].slice.call(newBlock.querySelectorAll('[contenteditable]'))
    if(typeof richs !== 'undefined' && richs !== null && richs.length > 0) {
      Array.prototype.forEach.call(richs, (rich) => {
        rich.remove()
      })
      var newRichs = [].slice.call(newBlock.querySelectorAll('.rich'))
      Array.prototype.forEach.call(newRichs, (newRich) => {
        new RichText(newRich, this.color)
      })
    }

    return newNumber
  }
}
